==> scripts-1.9.1-alpha.1.tgz: package/ssrConfig/webpack.dev.server.js <==
const webpack = require('webpack');
const ESLintPlugin = require('eslint-webpack-plugin');
const nodeExternals = require('webpack-node-externals');
const { merge } = require('webpack-merge');
const { getProjectPath } = require('../common/utils');
const baseConfig = require('./webpack.base');

module.exports = function (appConfig, extendEnv, { isServer, isHotServer, isProd }) {
  return merge(
    baseConfig(appConfig, extendEnv, {
      isServer,
      isHotServer,
      isProd
    }),
    {
      // 告诉 webpack打包的是 node端代码，避免把nodejs内置的模块打包到输出文件中，例如 fs path
      target: 'node',
      // 避免把 node_modules包下的第三方模块中包含的 nodejs内置的模块打包到出书文件中
      externals: nodeExternals({
        // 当然外部的css还是可以打进来的
        allowlist: /\.(js|css|less|scss|png|jpg|jpeg)$/
      }),
      // 入口文件
      entry: getProjectPath('/src/serverEntry/index.tsx'),
      // 输出信息
      output: {
        path: getProjectPath('/devBuild'),
        publicPath: '/',
        // 输出文件名
        filename: 'bundle.js',
        libraryTarget: 'commonjs2'
      },
      module: {
        rules: [
          {
            oneOf: [
              {
                test: /\.(scss|css|sass)$/,
                use: [
                  {
                    loader: require.resolve('ignore-loader')
                  }
                ]
              }
            ]
          }
        ]
      },
      // 覆盖查找规则， 减少无用模块
      plugins: [
        // eslint只在本地开发时检测
        new ESLintPlugin({
          exclude: 'node_modules',
          threads: 4,
          failOnError: false,
          lintDirtyModulesOnly: isProd,
          extensions: ['tsx', 'ts', 'js']
        }),
        new webpack.ContextReplacementPlugin(/any-promise/)
      ],
      // 避免路径丢失
      node: {
        __filename: true,
        __dirname: true
      }
    }
  );
};

==> scripts-3.0.0-alpha.1.tgz: package/ssrConfig/webpack.dev.server.js <==
const webpack = require('webpack');
const nodeExternals = require('webpack-node-externals');
const { merge } = require('webpack-merge');
const { getProjectPath } = require('../common/utils');
const baseConfig = require('./webpack.base');

module.exports = function (appConfig, extendEnv, { isServer, isHotServer, isProd }) {
  return merge(
    baseConfig(appConfig, extendEnv, {
      isServer,
      isHotServer,
      isProd
    }),
    {
      // 告诉 webpack打包的是 node端代码，避免把nodejs内置的模块打包到输出文件中，例如 fs path
      target: 'node',
      // 避免把 node_modules包下的第三方模块中包含的 nodejs内置的模块打包到出书文件中
      externals: nodeExternals({
        // 当然外部的css还是可以打进来的
        allowlist: /\.(js|css|less|scss|png|jpg|jpeg)$/
      }),
      // 入口文件
      entry: getProjectPath(appConfig.serverEntryAtSsr),
      // 输出信息
      output: {
        entry: getProjectPath(appConfig.serverOutputPathAtSsr),
        publicPath: '/',
        // 输出文件名
        filename: 'index.js',
        libraryTarget: 'commonjs2'
      },
      module: {
        rules: [
          {
            oneOf: [
              {
                test: /\.(scss|css|sass)$/,
                use: [
                  {
                    loader: require.resolve('ignore-loader')
                  }
                ]
              }
            ]
          }
        ]
      },
      // 覆盖查找规则， 减少无用模块
      plugins: [new webpack.ContextReplacementPlugin(/any-promise/)],
      // 避免路径丢失
      node: {
        __filename: true,
        __dirname: true
      }
    }
  );
};
